
Single application-level logging
-------

**Description:**

Whenever the application contains a single application-level logging implementation it 
becomes clear, transparent and easy to maintain. It also reduces the possibility that you 
overlook high priority logging.


**Solution:**

Verify that there is a single application-level logging implementation that is used by 
the software.
